==> lsh-0.1.8.tar.gz: lsh-0.1.8/src/blocking_write.c <==
/* blocking_write.c
 *
 * $id:$ */

/* lsh, an implementation of the ssh protocol
 *
 * Copyright (C) 1998 Niels Mller
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "blocking_write.h"

#include "io.h"
#include "xalloc.h"

/* GABA:
   (class
     (name blocking_write)
     (super abstract_write)
     (vars
       (fd . int)
       (write . (pointer (function void
                          int UINT32 "UINT8 *" "struct exception_handler *e")))))
*/

#include "blocking_write.c.x"

#if 0
static struct io_exception blocking_io_exception =
STATIC_IO_EXCEPTION(EXC_IO_BLOCKING_WRITE, "Blocking write failed");
#endif

static void do_blocking_write(struct abstract_write *w,
			      struct lsh_string *packet,
			      struct exception_handler *e)
{
  CAST(blocking_write, closure, w);

  closure->write(closure->fd, packet->length, packet->data, e);

  lsh_string_free(packet);
}

struct abstract_write *make_blocking_write(int fd, int with_nonblocking)
{
  NEW(blocking_write, closure);

  closure->super.write = do_blocking_write;
  closure->write = (with_nonblocking ? write_raw_with_poll : write_raw);
  closure->fd = fd;

  return &closure->super;
}

==> lsh-0.1.10.tar.gz: lsh-0.1.10/src/blocking_write.c <==
/* blocking_write.c
 *
 * $id:$ */

/* lsh, an implementation of the ssh protocol
 *
 * Copyright (C) 1998 Niels Mller
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "blocking_write.h"

#include "io.h"
#include "xalloc.h"

/* GABA:
   (class
     (name blocking_write)
     (super abstract_write)
     (vars
       (fd . int)
       (e object exception_handler)
       (write . (pointer (function void
                          int UINT32 "UINT8 *" "struct exception_handler *e")))))
*/

#include "blocking_write.c.x"

static void do_blocking_write(struct abstract_write *w,
			      struct lsh_string *packet)
{
  CAST(blocking_write, closure, w);

  closure->write(closure->fd, packet->length, packet->data, closure->e);
  
  lsh_string_free(packet);
}

struct abstract_write *
make_blocking_write(int fd, int with_nonblocking,
		    struct exception_handler *e)
{
  NEW(blocking_write, closure);

  closure->super.write = do_blocking_write;
  closure->write = (with_nonblocking ? write_raw_with_poll : write_raw);
  closure->e = e;
  closure->fd = fd;

  return &closure->super;
}
